@@ -26,7 +26,7 @@ class simStatus():
             
             print()
             print("Please report any problem to khalil.youssefi@aau.at")
-    def sendStatus(self,progress : int,status=None):
+    def sendStatus(self,progress : float,status=None):
         self.progress = progress
         URL = "https://simstatus.nes.aau.at/backend.php"
         PARAMS = {'handle':'h363652','p1':self.id,'p3':self.progress}
@@ -34,13 +34,12 @@ class simStatus():
             self.status = status
             PARAMS['p2'] = self.status
         return requests.get(url = URL, params = PARAMS, verify=True).content.decode('utf-8') == '1'
-class sendStatus():
-    def __init__(self,key,progress : int,status=None):
-        URL = "https://simstatus.nes.aau.at/backend.php"
-        PARAMS = {'handle':'h363654','p1':key,'p3':progress}
-        if status is not None:
-            PARAMS['p2'] = status
-        if(requests.get(url = URL, params = PARAMS, verify=True).content.decode('utf-8') == '1'):
-            print("updated!")
-        else:
-            print("something went wrong, sorry!")
\ No newline at end of file
+def sendStatus(key,progress : int,status=None):
+    URL = "https://simstatus.nes.aau.at/backend.php"
+    PARAMS = {'handle':'h363654','p1':key,'p3':progress}
+    if status is not None:
+        PARAMS['p2'] = status
+    if(requests.get(url = URL, params = PARAMS, verify=True).content.decode('utf-8') == '1'):
+        return "updated!"
+    else:
+        return "something went wrong, sorry!"
\ No newline at end of file
